import React from 'react';
import { Card, Button, Row, Col, Typography, Space } from 'antd';
import { 
  PlusOutlined, 
  FileTextOutlined, 
  RocketOutlined,
  CodeOutlined 
} from '@ant-design/icons';
import { useNavigate } from 'react-router';

const { Title, Paragraph } = Typography;

export const AppCreateChoice = () => {
  const navigate = useNavigate();

  return (
    <div style={{ padding: '24px', maxWidth: '1200px', margin: '0 auto' }}>
      <Space direction="vertical" size="large" style={{ width: '100%' }}>
        <div style={{ textAlign: 'center', marginBottom: '32px' }}>
          <Title level={2}>
            <RocketOutlined style={{ marginRight: '8px' }} />
            Create New Application
          </Title>
          <Paragraph style={{ fontSize: '16px', color: '#666' }}>
            Choose how you'd like to create your new application
          </Paragraph>
        </div>

        <Row gutter={[24, 24]} justify="center">
          <Col xs={24} md={12} lg={10}>
            <Card
              hoverable
              style={{ height: '320px', cursor: 'pointer' }}
              onClick={() => navigate('/apps/create/manual')}
              cover={
                <div style={{ 
                  padding: '40px', 
                  textAlign: 'center', 
                  background: 'linear-gradient(135deg, #667eea 0%, #764ba2 100%)',
                  color: 'white'
                }}>
                  <PlusOutlined style={{ fontSize: '48px' }} />
                </div>
              }
            >
              <Card.Meta
                title={
                  <Title level={4} style={{ marginBottom: '8px' }}>
                    Create Manually
                  </Title>
                }
                description={
                  <Space direction="vertical" size="small">
                    <Paragraph style={{ marginBottom: '16px' }}>
                      Build your application step by step by selecting existing components 
                      or creating new ones from scratch.
                    </Paragraph>
                    <ul style={{ paddingLeft: '20px', margin: 0 }}>
                      <li>Full control over configuration</li>
                      <li>Choose from existing components</li>
                      <li>Customize every detail</li>
                    </ul>
                  </Space>
                }
              />
            </Card>
          </Col>

          <Col xs={24} md={12} lg={10}>
            <Card
              hoverable
              style={{ height: '320px', cursor: 'pointer' }}
              onClick={() => navigate('/apps/import-compose')}
              cover={
                <div style={{ 
                  padding: '40px', 
                  textAlign: 'center', 
                  background: 'linear-gradient(135deg, #f093fb 0%, #f5576c 100%)',
                  color: 'white'
                }}>
                  <FileTextOutlined style={{ fontSize: '48px' }} />
                </div>
              }
            >
              <Card.Meta
                title={
                  <Title level={4} style={{ marginBottom: '8px' }}>
                    Import from docker-compose.yml
                  </Title>
                }
                description={
                  <Space direction="vertical" size="small">
                    <Paragraph style={{ marginBottom: '16px' }}>
                      Quickly import an existing multi-service application by providing 
                      your Git repository with a docker-compose.yml file.
                    </Paragraph>
                    <ul style={{ paddingLeft: '20px', margin: 0 }}>
                      <li>Automatic service detection</li>
                      <li>Fast onboarding</li>
                      <li>Import existing projects</li>
                    </ul>
                  </Space>
                }
              />
            </Card>
          </Col>
        </Row>

        <div style={{ textAlign: 'center', marginTop: '32px' }}>
          <Space size="large">
            <Button 
              size="large"
              icon={<CodeOutlined />}
              onClick={() => navigate('/apps/create/manual')}
            >
              Create Manually
            </Button>
            <Button 
              type="primary" 
              size="large"
              icon={<FileTextOutlined />}
              onClick={() => navigate('/apps/import-compose')}
            >
              Import from Compose
            </Button>
          </Space>
        </div>
      </Space>
    </div>
  );
};
